@@ -40,14 +40,14 @@ import re
 import time
 
 import six
-if six.PY2:
-	from io import open
 
 import univention.config_registry_info as cri
 from univention.config_registry.backend import exception_occured, SCOPE, ConfigRegistry
 from univention.config_registry.handler import run_filter, ConfigHandlers
 from univention.config_registry.misc import validate_key, escape_value
 from univention.config_registry.filters import filter_shell, filter_keys_only, filter_sort
+if six.PY2:
+	from io import open
 try:
 	from typing import Any, Callable, Dict, IO, Iterator, List, NoReturn, Optional, Tuple  # noqa F401
 except ImportError:  # pragma: no cover
@@ -157,7 +157,8 @@ def handler_set(args, opts=dict(), quiet=False):
 			key = arg[0:sep]
 			value = arg[sep + 1:]
 			key_exists = key in ucr._layer
-			if (not key_exists or sep == sep_set) and validate_key(key):
+			do_set_value = (not key_exists or sep == sep_set)
+			if do_set_value and validate_key(key):
 				if not quiet:
 					if key_exists:
 						print('Setting %s' % key)
@@ -165,6 +166,8 @@ def handler_set(args, opts=dict(), quiet=False):
 						print('Create %s' % key)
 				changes[key] = value
 			else:
+				if do_set_value:
+					opts['exit_code'] = 1
 				if not quiet:
 					if key_exists:
 						print('Not updating %s' % key)
@@ -716,7 +719,7 @@ OPT_COMMANDS = {
 
 
 def main(args):
-	# type: (List[str]) -> None
+	# type: (List[str]) -> int
 	"""Run config registry."""
 	try:
 		# close your eyes ...
@@ -821,9 +824,10 @@ def main(args):
 				missing_parameter(action)
 
 			# if any filter option is set
+			cmd_opts['exit_code'] = 0
 			result = handler_func(args, cmd_opts)
 			if result is None:
-				return
+				return cmd_opts['exit_code']
 
 			results = result
 			# let the filter options do their job
@@ -839,5 +843,6 @@ def main(args):
 		if OPT_ACTIONS['debug'][1]:
 			raise
 		exception_occured()
+	return cmd_opts['exit_code']
 
 # vim:set sw=4 ts=4 noet:
